==> qcad-3.32.4.0-2-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation type="unfinished">Navpično/vodoravno</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation type="unfinished">Nazaj</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Prilagojeno</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Mreža</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Konec</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Na entiteti</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Pravokotno</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tangencialno</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Središče</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Sredina</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Presečišče</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Referenca</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation type="unfinished">Razdalja</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Neveljavno</translation>
    </message>
</context>
</TS>

==> qcad-3.32.4.4-3-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>Navpično/vodoravno</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Prilagojeno</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Mreža</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Konec</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Na entiteti</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Pravokotno</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tangencialno</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Središče</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Sredina</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Presečišče</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Referenca</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>Razdalja</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Neveljavno</translation>
    </message>
</context>
</TS>
